--Skill 1.2 Design and implement dimensions in a cube
----LISTING 1-1 Named query statement to arbitrarily assign managers to employees
SELECT 
    [Employee Key],
	CASE 
	    WHEN [WWI Employee ID] >= 3 AND [WWI Employee ID] <= 11 THEN 194
		WHEN [WWI Employee ID] >= 12 AND [WWI Employee ID] <= 15 THEN 203
		WHEN [WWI Employee ID] >= 16 AND [WWI Employee ID] <= 19 THEN 208
		WHEN [WWI Employee ID] = 20 THEN 210
		ELSE NULL
	END AS [Manager Key],
	[WWI Employee ID],
	[Employee],
	[Preferred Name],
	[Is Salesperson],
	[Photo],
	[Valid From],
	[Valid To],
	[Lineage Key]
FROM [Dimension].[Employee];

----LISTING 1-2 Named query statement to remove Bill To Customer Key to Sale
SELECT 
    [Sale Key],
    [City Key],
    [Customer Key],
    [Stock Item Key],
    [Invoice Date Key],
    [Delivery Date Key],
    [Salesperson Key],
    [WWI Invoice ID],
    [Description],
    [Package],
    [Quantity],
    [Unit Price],
    [Tax Rate],
    [Total Excluding Tax],
    [Tax Amount],
    [Profit],
    [Total Including Tax],
    [Total Dry Items],
    [Total Chiller Items]
FROM [Fact].[Sale];

----LISTING 1-3 Named query statement to add Bill To Customer Key to Customer
SELECT 
    c1.[Customer Key],
    c2.[Customer Key] as [Bill To Customer Key],
    c1.[WWI Customer ID],
    c1.Customer,
	  c1.Category,
    c1.[Buying Group],
    c1.[Primary Contact],
    c1.[Postal Code]
FROM [WideWorldImportersDW].[Dimension].[Customer] c1
LEFT OUTER JOIN [WideWorldImportersDW].[Dimension].[Customer] c2
    ON c1.[Bill To Customer] = c2.[Customer];

----LISTING 1-4 Named query statement to create Bill To Customer
SELECT 
    [Customer Key] AS [Bill To Customer Key],
    [Customer] AS [Bill To Cutomer]
FROM [Dimension].[Customer]
WHERE
    [Customer Key] in (1, 202);

----LISTING 1-5 Named query statement to create Sales Reason dimension 
SELECT
    1 AS SalesReasonKey, 'Value' AS SalesReason
UNION
SELECT
    2 AS SalesReasonKey, 'Manufacturer' AS SalesReason
UNION
SELECT
    3 AS SalesReasonKey, 'Sales Person' AS SalesReason;


----LISTING 1-6 Named query statement to create Sales Reason fact bridge
SELECT 
    CAST(1 AS bigint) AS [Sale Key],
    1 AS SalesReasonKey
UNION
SELECT
    CAST(1 AS bigint) AS [Sale Key],
    2 AS SalesReasonKey
UNION
SELECT
    CAST(1 AS bigint) AS [Sale Key],
    3 AS SalesReasonKey
UNION
SELECT
    CAST(2 AS bigint) AS [Sale Key],
    1 AS SalesReasonKey;


----LISTING 1-7 Insert a row into the sales fact table for a current stock item
INSERT INTO [Fact].[Sale] 
  ([City Key],
   [Customer Key],
   [Bill To Customer Key],
   [Stock Item Key],
   [Invoice Date Key],
   [Delivery Date Key],
   [Salesperson Key],
   [WWI Invoice ID],
   [Description],
   [Package],
   [Quantity],
   [Unit Price],
   [Tax Rate],
   [Total Excluding Tax],
   [Tax Amount],
   [Profit],
   [Total Including Tax],
   [Total Dry Items],
   [Total Chiller Items],
   [Lineage Key])
VALUES
  (0,
   0,
   0,
   604,
   '2016-05-31',
   '2016-05-31', 
   0, 
   70511,
   'USB rocket launcher (Gray)',
   'Each', 
   1000,
   25, 
   15, 
   25000, 
   3750, 
   15500,
   28750, 
   1000, 
   0, 
   11);
GO

----LISTING 1-8 Retrieve aggregate results from a relational database by using a GROUP BY clause
USE WideWorldImportersDW;
GO
SELECT
    Color,
	Size,
	SUM(Quantity) AS QuantitySold
FROM Fact.Sale s
INNER JOIN Dimension.[Stock Item] si 
    ON s.[Stock Item Key] = si.[Stock Item Key]
GROUP BY
    Color,
	Size;

----LISTING 1-9 Review results of query generated by SSAS for populating the ISO Week Number attribute
SELECT 
DISTINCT
[Dimension_Date].[ISO Week Number] AS 
    [Dimension_DateISO_x0020_Week_x0020_Number0_0],
[Dimension_Date].[Calendar Year Label] AS   
    [Dimension_DateCalendar_x0020_Year_x0020_Label0_1]
FROM [Dimension].[Date] AS [Dimension_Date]
ORDER BY [Dimension_Date].[ISO Week Number];


----LISTING 1-10 Named query to simulate changes in stock item inventory over time
SELECT
    CONVERT(date,'2013-01-01') as DateKey,
    [Stock Item Key],
    [Quantity On Hand],
    [Bin Location],
    [Reorder Level],
    [Target Stock Level]
FROM
    Fact.[Stock Holding]
UNION ALL
SELECT     
    CONVERT(date, '2013-06-01') as DateKey,   
    [Stock Item Key],
    [Quantity On Hand] - [Stock Item Key] AS [Quantity On Hand], 
    [Bin Location], 
    [Reorder Level], 
[Target Stock Level]
FROM            
    Fact.[Stock Holding] AS t; 


----Validate MDX expression
SELECT
    SUM(Profit) / SUM([Total Excluding Tax]) AS ProfitMarginPercent
FROM Fact.Sale;

